@@ -11,7 +11,9 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 import os
+import sys
 
+from six import text_type
 from dateutil.parser import parse
 from dateutil.tz import tzlocal
 
@@ -19,6 +21,29 @@ from awscli.customizations.s3.fileinfo import FileInfo
 from awscli.customizations.s3.utils import find_bucket_key, get_file_stat
 
 
+# This class is provided primarily to provide a detailed error message.
+
+class FileDecodingError(Exception):
+    """Raised when there was an issue decoding the file."""
+
+    ADVICE = (
+        "Please check your locale settings.  The filename was decoded as: %s\n"
+        "On posix platforms, check the LC_CTYPE environment variable."
+            % (sys.getfilesystemencoding())
+    )
+
+    def __init__(self, directory, filename):
+        self.directory = directory
+        self.file_name = filename
+        self.error_message = (
+            'There was an error trying to decode the the file "%s" in '
+            'directory "%s". \n%s' % (self.file_name,
+                                      self.directory.encode('utf-8'),
+                                      self.ADVICE)
+        )
+        super(FileDecodingError, self).__init__(self.error_message)
+
+
 class FileGenerator(object):
     """
     This is a class the creates a generator to yield files based on information
@@ -89,6 +114,7 @@ class FileGenerator(object):
             # separator to any directories.  We can then sort the contents,
             # and ensure byte order.
             names = listdir(path)
+            self._check_paths_decoded(path, names)
             for i, name in enumerate(names):
                 file_path = join(path, name)
                 if isdir(file_path):
@@ -108,6 +134,17 @@ class FileGenerator(object):
                     size, last_update = get_file_stat(file_path)
                     yield file_path, size, last_update
 
+    def _check_paths_decoded(self, path, names):
+        # We can get a UnicodeDecodeError if we try to listdir(<unicode>) and
+        # can't decode the contents with sys.getfilesystemencoding().  In this
+        # case listdir() returns the bytestring, which means that
+        # join(<unicode>, <str>) could raise a UnicodeDecodeError.  When this
+        # happens we raise a FileDecodingError that provides more information
+        # into what's going on.
+        for name in names:
+            if not isinstance(name, text_type):
+                raise FileDecodingError(path, name)
+
     def list_objects(self, s3_path, dir_op):
         """
         This function yields the appropriate object or objects under a
