@@ -80,10 +80,9 @@ class S3Handler(object):
             self.result_queue.join()
 
         except Exception as e:
-            LOGGER.error('Exception caught during task execution: %s',
-                          str(e))
-            # Log the traceback at DEBUG level.
-            LOGGER.debug(str(e), exc_info=True)
+            LOGGER.debug('Exception caught during task execution: %s',
+                         str(e), exc_info=True)
+            self.result_queue.put({'message': str(e), 'error': True})
         except KeyboardInterrupt:
             self.interrupt.set()
             self.result_queue.put({'message': "Cleaning up. Please wait...",
