@@ -38,6 +38,7 @@ from awscli.customizations.dryrundocs import register_dryrun_docs
 from awscli.customizations.route53resourceid import register_resource_id
 from awscli.customizations.configure import register_configure_cmd
 from awscli.customizations.cloudtrail import initialize as cloudtrail_init
+from awscli.customizations.toplevelbool import register_bool_params
 
 
 def awscli_initialize(event_handlers):
@@ -79,3 +80,4 @@ def awscli_initialize(event_handlers):
     register_resource_id(event_handlers)
     register_configure_cmd(event_handlers)
     cloudtrail_init(event_handlers)
+    register_bool_params(event_handlers)
